@@ -1,26 +1,25 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright © 2008-2009  Ricky Zhou, Red Hat, Inc. All rights reserved.
-#
-# This copyrighted material is made available to anyone wishing to use, modify,
-# copy, or redistribute it subject to the terms and conditions of the GNU
-# General Public License v.2.  This program is distributed in the hope that it
-# will be useful, but WITHOUT ANY WARRANTY expressed or implied, including the
-# implied warranties of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-# See the GNU General Public License for more details.  You should have
-# received a copy of the GNU General Public License along with this program;
-# if not, write to the Free Software Foundation, Inc., 51 Franklin Street,
-# Fifth Floor, Boston, MA 02110-1301, USA. Any Red Hat trademarks that are
-# incorporated in the source code or documentation are not subject to the GNU
-# General Public License and may only be used or replicated with the express
-# permission of Red Hat, Inc.
-#
-# Author(s): Ricky Zhou <ricky@fedoraproject.org>
-#            Toshio Kuratomi <tkuratom@redhat.com>
+# Copyright (C) 2008-2009  Ricky Zhou, Red Hat, Inc.
+# This file is part of python-fedora
+# 
+# python-fedora is free software; you can redistribute it and/or
+# modify it under the terms of the GNU Lesser General Public
+# License as published by the Free Software Foundation; either
+# version 2.1 of the License, or (at your option) any later version.
+# 
+# python-fedora is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+# Lesser General Public License for more details.
+# 
+# You should have received a copy of the GNU Lesser General Public
+# License along with python-fedora; if not, see <http://www.gnu.org/licenses/>
 #
 '''
 Provide a client module for talking to the Fedora Account System.
 
+
 .. moduleauthor:: Ricky Zhou <ricky@fedoraproject.org>
 .. moduleauthor:: Toshio Kuratomi <tkuratom@redhat.com>
 '''
@@ -141,8 +140,34 @@ class AccountSystem(BaseClient):
                 109464: 'cassmodiah@fedoraproject.org',
                 # Robert M. Albrecht: romal@gmx.de
                 101475: 'mail@romal.de',
-                # David Nielsen: gnomeuser@gmail.com
-                100506: 'dnielsen@fedoraproject.org ',
+                # Mathieu Bridon: mathieu.bridon@gmail.com
+                100753: 'bochecha@fedoraproject.org',
+                # Davide Cescato: davide.cescato@iaeste.ch
+                123204: 'ceski@fedoraproject.org',
+                # Nick Bebout: nick@bebout.net
+                101458: 'nb@fedoraproject.org',
+                # Niels Haase: haase.niels@gmail.com
+                126862: 'arxs@fedoraproject.org',
+                # Thomas Janssen: th.p.janssen@googlemail.com
+                103110: 'thomasj@fedoraproject.org',
+                # Michael J Gruber: 'michaeljgruber+fedoraproject@gmail.com'
+                105113: 'mjg@fedoraproject.org',
+                # Juan Manuel Rodriguez Moreno: 'nushio@gmail.com'
+                101302: 'nushio@fedoraproject.org',
+                # Andrew Cagney: 'andrew.cagney@gmail.com'
+                102169: 'cagney@fedoraproject.org',
+                # Jeremy Katz: 'jeremy@katzbox.net'
+                100036: 'katzj@fedoraproject.org',
+                # Dominic Hopf: 'dmaphy@gmail.com'
+                124904: 'dmaphy@fedoraproject.org',
+                # Christoph Wickert: 'christoph.wickert@googlemail.com':
+                100271: 'cwickert@fedoraproject.org',
+                # Elliott Baron: 'elliottbaron@gmail.com'
+                106760: 'ebaron@fedoraproject.org',
+                # Nigel Jones
+                101468: 'nigjones@redhat.com',
+                # Thomas Spura: 'spurath@students.uni-mainz.de'
+                111433: 'tomspur@fedoraproject.org',
                 }
         # A few people have an email account that is used in owners.list but
         # have setup a bugzilla account for their primary account system email
@@ -170,7 +195,7 @@ class AccountSystem(BaseClient):
 
     def group_by_id(self, group_id):
         '''Returns a group object based on its id'''
-        params = {'id': int(group_id)}
+        params = {'group_id': int(group_id)}
         request = self.send_request('json/group_by_id', auth = True,
                 req_params = params)
         if request['success']:
@@ -214,7 +239,7 @@ class AccountSystem(BaseClient):
     def person_by_id(self, person_id):
         '''Returns a person object based on its id'''
         person_id = int(person_id)
-        params = {'id': person_id}
+        params = {'person_id': person_id}
         request = self.send_request('json/person_by_id', auth=True,
                 req_params=params)
 
@@ -224,6 +249,12 @@ class AccountSystem(BaseClient):
                         self.__bugzilla_email[person_id]
             else:
                 request['person']['bugzilla_email'] = request['person']['email']
+            # In the new FAS, membership info is returned separately
+            if 'approved' in request:
+                request['person']['approved_memberships'] = request['approved']
+            if 'unapproved' in request:
+                request['person']['unapproved_memberships'] = \
+                        request['unapproved']
             return request['person']
         else:
             return dict()
@@ -240,6 +271,12 @@ class AccountSystem(BaseClient):
                 person['bugzilla_email'] = self.__bugzilla_email[person['id']]
             else:
                 person['bugzilla_email'] = person['email']
+            # In the new FAS, membership info is returned separately
+            if 'approved' in request:
+                request['person']['approved_memberships'] = request['approved']
+            if 'unapproved' in request:
+                request['person']['unapproved_memberships'] = \
+                        request['unapproved']
             return person
         else:
             return dict()
@@ -348,18 +385,15 @@ class AccountSystem(BaseClient):
         return people
 
     def people_by_id(self):
-        # Note: The FAS server must be upgraded before people_by_key() will
-        # work
-        #'''*Deprecated* Use people_by_key() instead.
-        '''
+        '''*Deprecated* Use people_by_key() instead.
+
         Returns a dict relating user IDs to human_name, email, username,
         and bugzilla email
         '''
-        #warnings.warn(_("people_by_id() is deprecated and will be removed in"
-        #    " 0.4.  Please port your code to use people_by_key(key='id',"
-        #    " fields=['human_name', 'email', 'username', 'bugzilla_email'])"
-        #    " instead"),
-        #    DeprecationWarning, stacklevel=2)
+        warnings.warn(_("people_by_id() is deprecated and will be removed in"
+            " 0.4.  Please port your code to use people_by_key(key='id',"
+            " fields=['human_name', 'email', 'username', 'bugzilla_email'])"
+            " instead"), DeprecationWarning, stacklevel=2)
 
         request = self.send_request('/json/user_id', auth=True)
         user_to_id = {}
@@ -461,12 +495,43 @@ class AccountSystem(BaseClient):
         if 'exc' in request:
             raise AppError(name = request['exc'], message = request['tg_flash'])
 
+    def people_query(self, constraints=None, columns=None):
+        '''Returns a list of dicts representing database rows
+
+        :arg constraints: A dictionary specifying WHERE constraints on columns
+        :arg columns: A list of columns to be selected in the query
+        :raises AppError: if the query failed on the server (most likely
+            because  the server was given a bad query)
+        :returns: A list of dicts representing database rows (the keys of
+            the dict are the columns requested)
+
+        .. versionadded:: 0.3.12.1
+        '''
+        if constraints is None:
+            constraints = {}
+        if columns is None:
+            columns = []
+
+        req_params = {}
+        req_params.update(constraints)
+        req_params['columns'] = ','.join(columns)
+
+        try:
+            request = self.send_request('json/people_query',
+                req_params=req_params, auth=True)
+            if request['success']:
+                return request['data']
+            else:
+                raise AppError(message=request['error'], name='FASError')
+        except FedoraServiceError:
+            raise
+
     ### Certs ###
 
     def user_gencert(self):
         '''Generate a cert for a user'''
         try:
-            request = self.send_request('user/gencert', auth=True)
+            request = self.send_request('user/dogencert', auth=True)
         except FedoraServiceError:
             raise
         if not request['cla']:
@@ -495,17 +560,24 @@ class AccountSystem(BaseClient):
 
     ### fasClient Special Methods ###
 
-    def group_data(self):
+    def group_data(self, force_refresh=None):
         '''Return administrators/sponsors/users and group type for all groups
 
+        :arg force_refresh: If true, the returned data will be queried from the
+            database, as opposed to memcached.
         :raises AppError: if the query failed on the server
         :returns: A dict mapping group names to the group type and the
             user IDs of the administrator, sponsors, and users of the group.
 
         .. versionadded:: 0.3.8
         '''
+        params = {}
+        if force_refresh:
+            params['force_refresh'] = True
+
         try:
-            request = self.send_request('json/fas_client/group_data', auth=True)
+            request = self.send_request('json/fas_client/group_data',
+                req_params=params, auth=True)
             if request['success']:
                 return request['data']
             else:
