@@ -1,27 +1,27 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright © 2008  Red Hat, Inc. All rights reserved.
-# Copyright © 2008  Ricky Zhou. All rights reserved.
-#
-# This copyrighted material is made available to anyone wishing to use, modify,
-# copy, or redistribute it subject to the terms and conditions of the GNU
-# General Public License v.2.  This program is distributed in the hope that it
-# will be useful, but WITHOUT ANY WARRANTY expressed or implied, including the
-# implied warranties of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-# See the GNU General Public License for more details.  You should have
-# received a copy of the GNU General Public License along with this program;
-# if not, write to the Free Software Foundation, Inc., 51 Franklin Street,
-# Fifth Floor, Boston, MA 02110-1301, USA. Any Red Hat trademarks that are
-# incorporated in the source code or documentation are not subject to the GNU
-# General Public License and may only be used or replicated with the express
-# permission of Red Hat, Inc.
-#
-# Author(s): Toshio Kuratomi <tkuratom@redhat.com>
-#             Ricky Zhou <ricky@fedoraproject.org>
+# Copyright (C) 2008-2009  Red Hat, Inc.
+# Copyright (C) 2008  Ricky Zhou
+# This file is part of python-fedora
+# 
+# python-fedora is free software; you can redistribute it and/or
+# modify it under the terms of the GNU Lesser General Public
+# License as published by the Free Software Foundation; either
+# version 2.1 of the License, or (at your option) any later version.
+# 
+# python-fedora is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+# Lesser General Public License for more details.
+# 
+# You should have received a copy of the GNU Lesser General Public
+# License along with python-fedora; if not, see <http://www.gnu.org/licenses/>
 #
 '''
 Miscellaneous functions of use on a TurboGears Server
 
+.. versionchanged:: 0.3.11
+   Save the original turbogears.url function as :func:`fedora.tg.util.tg_url`
 
 .. moduleauthor:: Toshio Kuratomi <tkuratom@redhat.com>
 .. moduleauthor:: Ricky Zhou <ricky@fedoraproject.org>
@@ -42,6 +42,11 @@ from turbogears.controllers import check_app_root
 from turbogears.identity.exceptions import RequestRequiredException
 from decorator import decorator
 
+from fedora import _
+
+
+tg_url = turbogears.url
+
 def fedora_template(template, template_type='genshi'):
     '''Function to return the path to a template.
 
@@ -50,6 +55,8 @@ def fedora_template(template, template_type='genshi'):
         Defaults to 'genshi'
     :returns: filesystem path to the template
     '''
+    # :E1101: pkg_resources does have resource_filename
+    # pylint: disable-msg=E1101
     return pkg_resources.resource_filename('fedora', os.path.join('tg',
         'templates', template_type, template))
 
@@ -57,7 +64,7 @@ def add_custom_stdvars(new_vars):
     return new_vars.update({'fedora_template': fedora_template})
 
 def url(tgpath, tgparams=None, **kwargs):
-    """Computes URLs.
+    '''Computes URLs.
 
     This is a replacement for :func:`turbogears.controllers.url` (aka
     :func:`tg.url` in the template).  In addition to the functionality that
@@ -76,7 +83,7 @@ def url(tgpath, tgparams=None, **kwargs):
 
     .. versionadded:: 0.3.10
        Modified from turbogears.controllers.url for :ref:`CSRF-Protection`
-    """
+    '''
     if not isinstance(tgpath, basestring):
         tgpath = '/'.join(list(tgpath))
     if tgpath.startswith('/'):
@@ -98,20 +105,20 @@ def url(tgpath, tgparams=None, **kwargs):
             tgparams = tgparams.copy()
             tgparams.update(kwargs)
         except AttributeError:
-            raise TypeError('url() expects a dictionary for query parameters')
+            raise TypeError(
+                    _('url() expects a dictionary for query parameters'))
     args = []
     # Add the _csrf_token
-    query_params = tgparams.iteritems()
     try:
         if identity.current.csrf_token:
-            query_params = chain(query_params,
-                    [('_csrf_token', identity.current.csrf_token)])
+            tgparams.update({'_csrf_token': identity.current.csrf_token})
     except RequestRequiredException: # pylint: disable-msg=W0704
         # :W0704: If we are outside of a request (called from non-controller
         # methods/ templates) just don't set the _csrf_token.
         pass
 
     # Check for query params in the current url
+    query_params = tgparams.iteritems()
     scheme, netloc, path, params, query_s, fragment = urlparse.urlparse(tgpath)
     if query_s:
         query_params = chain((p for p in cgi.parse_qsl(query_s) if p[0] !=
@@ -151,7 +158,7 @@ def enable_csrf():
     .. versionadded:: 0.3.10
        Added to enable :ref:`CSRF-Protection`
     '''
-    # Override the turbogears.url funciton with our own
+    # Override the turbogears.url function with our own
     turbogears.url = url
     turbogears.controllers.url = url
 
@@ -271,11 +278,11 @@ def json_or_redirect(forward_url):
     .. versionadded:: 0.3.7
        To make writing methods that use validation easier
     '''
-    def call(func, *args, **kw):
+    def call(func, *args, **kwargs):
         if request_format() == 'json':
-            return func(*args, **kw)
+            return func(*args, **kwargs)
         else:
-            func(*args, **kw)
+            func(*args, **kwargs)
             raise redirect(forward_url)
     return decorator(call)
 
