@@ -1,6 +1,29 @@
+# -*- coding: utf-8 -*-
+#
+# Copyright (C) 2007-2008  Red Hat, Inc.
+# This file is part of python-fedora
+# 
+# python-fedora is free software; you can redistribute it and/or
+# modify it under the terms of the GNU Lesser General Public
+# License as published by the Free Software Foundation; either
+# version 2.1 of the License, or (at your option) any later version.
+# 
+# python-fedora is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+# Lesser General Public License for more details.
+# 
+# You should have received a copy of the GNU Lesser General Public
+# License along with python-fedora; if not, see <http://www.gnu.org/licenses/>
+#
+# Adapted from code in the TurboGears project licensed under the MIT license.
+#
 '''
 This plugin provides integration with the Fedora Account System using JSON
 calls to the account system server.
+
+
+.. moduleauthor:: Toshio Kuratomi <tkuratom@redhat.com>
 '''
 
 from turbogears import config
